==> igniteui-react-charts-16.4.1.tgz: package/ES5/ColumnSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { ConsolidatedItemsPosition_$type } from "./ConsolidatedItemsPosition";
import { Type, runOn, enumGetBox, markType, fromEnum } from "igniteui-react-core/ES5/type";
import { Pool$1 } from "igniteui-react-core/ES5/Pool$1";
import { List$1 } from "igniteui-react-core/ES5/List$1";
import { ScalerParams } from "./ScalerParams";
import { Rectangle } from "igniteui-react-core/ES5/Rectangle";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { isNaN_, isInfinity } from "igniteui-react-core/ES5/number";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
var ColumnSeries = /** @class */ (function (_super) {
    tslib_1.__extends(ColumnSeries, _super);
    function ColumnSeries() {
        var _this = _super.call(this) || this;
        _this.qd = null;
        _this.p8 = 0;
        _this.ab = ColumnSeries.$;
        _this.pr = 2;
        return _this;
    }
    ColumnSeries.prototype.bf = function () {
        return new ColumnSeriesView(this);
    };
    ColumnSeries.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.p7 = a;
    };
    ColumnSeries.prototype.m7 = function () {
        return 1;
    };
    ColumnSeries.prototype.get_nm = function () {
        return true;
    };
    Object.defineProperty(ColumnSeries.prototype, "nm", {
        get: function () {
            return this.get_nm();
        },
        enumerable: true,
        configurable: true
    });
    ColumnSeries.prototype.preferredCategoryMode = function (a) {
        return this.pr;
    };
    ColumnSeries.prototype.ll = function (a) {
        if (this.qd == null) {
            this.qd = runOn(this, this.qa);
        }
        var b = this.pu != null ? this.pu : this.yAxis;
        var c = this.po;
        return this.ot.c$d(this, a, c, b, this.my, this.ny(this.bi), this.nz(this.bi), this.qd);
    };
    ColumnSeries.prototype.df = function (a, b) {
        if (this.di(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    };
    ColumnSeries.prototype.ho = function (a, b) {
        _super.prototype.ho.call(this, a, b);
        var c = b;
        if (a && c.c5 != null) {
            c.c5.count = 0;
        }
    };
    ColumnSeries.prototype.ec = function () {
        return this.po.jk(this.bi.bq, this.bi.bp, this.getEffectiveViewport1(this.bi));
    };
    ColumnSeries.prototype.oe = function (a, b) {
        _super.prototype.oe.call(this, a, b);
        var c = a.f;
        if (!b.q()) {
            return;
        }
        var d = b.bq;
        var e = b.bp;
        var f = this.getEffectiveViewport1(b);
        var g = new ScalerParams(0, d, e, this.pu.b8, f);
        g.b = this.ed();
        var h = new ScalerParams(0, d, e, this.po.b8, f);
        var i = this.pu;
        var j = i.dt(i.j7, g);
        var k = this.po.jk(d, e, f);
        var l = this.po;
        var m = b;
        if (isNaN_(k) || isInfinity(k)) {
            m.c5.count = 0;
            return;
        }
        this.m5.x(this, this.nq(), this.po, runOn(this, this.mr), this.ny(b), this.nz(b));
        this.m5.p = this.qb;
        this.m5.q = this.qc;
        this.m5.j = this.qb;
        this.m5.k = this.qc;
        var n = false;
        var o = this.m5.c;
        if (o != null) {
            n = true;
        }
        var p = this.po.cc;
        var q = p ? this.po : null;
        var r = this.valueColumn.count;
        var s = this.ny(b);
        var t = 0;
        for (var u = 0; u < c.count; ++u) {
            var v = c._inner[u][0] - 0.5 * k;
            var w = this.qa(c._inner[u]);
            var x = j;
            w = Math.max(w, -100);
            x = Math.min(x, e.bottom + 100);
            var y = Math.abs(x - w);
            if (isInfinity(y)) {
                continue;
            }
            var z = m.c5.item(t);
            t++;
            z.width = k;
            z.height = y;
            if (n) {
                this.oa(c, u, r, l, h, b.n);
            }
            if (z.dataContext != null) {
                var aa = z.dataContext;
                if (s == 1) {
                    var ab = this.m5.a(r, u)[0];
                    if (ab >= 0 && ab < this.bz.count) {
                        if (q != null && q.i$b != null && q.i$b.count > ab) {
                            ab = q.i$b._inner[ab];
                        }
                        aa.item = this.bz.item(ab);
                    }
                }
                else {
                    aa.item = null;
                }
            }
            this.m5.ae(z, false, false, false, false);
            z.al = this.m5.j;
            z.am = this.m5.k;
            m.da(z, v, Math.min(x, w));
        }
        m.c5.count = t;
        b.cs(a);
    };
    Object.defineProperty(ColumnSeries.prototype, "p9", {
        get: function () {
            return this.p8;
        },
        set: function (a) {
            if (this.p9 != a) {
                var b = this.p9;
                this.p8 = a;
                this.raisePropertyChanged("ConsolidatedColumnVerticalPosition", enumGetBox(ConsolidatedItemsPosition_$type, b), enumGetBox(ConsolidatedItemsPosition_$type, this.p9));
            }
        },
        enumerable: true,
        configurable: true
    });
    ColumnSeries.prototype.qa = function (a) {
        if (a == null || a.length < 3) {
            return NaN;
        }
        switch (this.p9) {
            case 0: return a[1];
            case 1: return a[2];
            case 2: return (a[1] + a[2]) / 2;
            case 3:
                var b = (a[1] + a[2]) / 2;
                if (this.yAxis == null) {
                    return b;
                }
                var c = this.yAxis.dw(b, new ScalerParams(1, this.bs.mz, this.bs.my, this.yAxis.b8));
                if (c < this.yAxis.j7) {
                    return a[2];
                }
                else {
                    return a[1];
                }
            case 4:
                var d = (a[1] + a[2]) / 2;
                var e = this.yAxis.dw(d, new ScalerParams(1, this.bs.mz, this.bs.my, this.yAxis.b8));
                if (this.yAxis == null) {
                    return d;
                }
                if (e < this.yAxis.j7) {
                    return a[1];
                }
                else {
                    return a[2];
                }
            default: return (a[1] + a[2]) / 2;
        }
    };
    Object.defineProperty(ColumnSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.nt;
        },
        enumerable: true,
        configurable: true
    });
    ColumnSeries.$t = markType(ColumnSeries, 'ColumnSeries', HorizontalAnchoredCategorySeries.$);
    return ColumnSeries;
}(HorizontalAnchoredCategorySeries));
export { ColumnSeries };
Type.dep(DependencyProperty, PropertyMetadata, ColumnSeries, 'raisePropertyChanged', ['RadiusX:qb:qh', [1, 2], 'RadiusY:qc:qi', [1, 2]]);
var ColumnSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(ColumnSeriesView, _super);
    function ColumnSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c4 = null;
        _this.c6 = null;
        _this.db = new Rectangle();
        _this.c5 = null;
        _this.c4 = a;
        _this.c5 = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.dc);
            $ret.activate = runOn(_this, _this.c7);
            $ret.disactivate = runOn(_this, _this.c9);
            $ret.destroy = runOn(_this, _this.c8);
            return $ret;
        })());
        return _this;
    }
    ColumnSeriesView.prototype.ap = function () {
        _super.prototype.ap.call(this);
        this.c6 = new List$1(Rectangle.$, 0);
        if (!this.n) {
            this.e.eq = 4;
            this.e.bj = 1;
        }
    };
    ColumnSeriesView.prototype.dc = function () {
        var a = new Rectangle();
        this.c6.add(a);
        a._visibility = 1;
        return a;
    };
    ColumnSeriesView.prototype.c7 = function (a) {
        a._visibility = 0;
    };
    ColumnSeriesView.prototype.c9 = function (a) {
        a._visibility = 1;
    };
    ColumnSeriesView.prototype.c8 = function (a) {
        this.c6.remove(a);
    };
    ColumnSeriesView.prototype.da = function (a, b, c) {
        if (!this.isDirty) {
            this.an();
        }
        a.o = c;
        a.n = b;
    };
    ColumnSeriesView.prototype.z = function (a) {
        return this.c6._inner[a];
    };
    ColumnSeriesView.prototype.y = function (a) {
        var b = this.c6._inner[a];
        this.db._visibility = b._visibility;
        this.db.n = b.n;
        this.db.o = b.o;
        this.db.width = b.width;
        this.db.height = b.height;
        var c = this.bl(a);
        this.db._fill = c;
        this.db._stroke = c;
        this.db.ac = this.e.eu + 3;
        return this.db;
    };
    ColumnSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d) {
            for (var c = 0; c < this.c6.count; c++) {
                var d = this.x(c, b);
                this.ba(d, c, b);
                a.v(d);
            }
        }
    };
    ColumnSeriesView.prototype.ai = function (a) {
        var e_1, _a, e_2, _b;
        _super.prototype.ai.call(this, a);
        var b = 0;
        var c = new List$1(Rectangle.$, 0);
        try {
            for (var _c = tslib_1.__values(fromEnum(this.c5.a)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var d = _d.value;
                c.add(d);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
            }
            finally { if (e_1) throw e_1.error; }
        }
        c.aa(function (e, f) {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        try {
            for (var _e = tslib_1.__values(fromEnum(c)), _f = _e.next(); !_f.done; _f = _e.next()) {
                var e = _f.value;
                this.e.a2.exportRectangleData(a, e, "column" + b, ["Main", "Fill"]);
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return)) _b.call(_e);
            }
            finally { if (e_2) throw e_2.error; }
        }
        b++;
    };
    ColumnSeriesView.$t = markType(ColumnSeriesView, 'ColumnSeriesView', AnchoredCategorySeriesView.$);
    return ColumnSeriesView;
}(AnchoredCategorySeriesView));
export { ColumnSeriesView };
/*<BeginStatics Name="Infragistics.Controls.Charts.ColumnSeries" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.ColumnSeries" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES5/ColumnSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { ConsolidatedItemsPosition_$type } from "./ConsolidatedItemsPosition";
import { Type, runOn, enumGetBox, markType, fromEnum } from "igniteui-react-core/ES5/type";
import { Pool$1 } from "igniteui-react-core/ES5/Pool$1";
import { Rectangle } from "igniteui-react-core/ES5/Rectangle";
import { List$1 } from "igniteui-react-core/ES5/List$1";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { isNaN_, isInfinity } from "igniteui-react-core/ES5/number";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
var ColumnSeries = /** @class */ (function (_super) {
    tslib_1.__extends(ColumnSeries, _super);
    function ColumnSeries() {
        var _this = _super.call(this) || this;
        _this.qe = null;
        _this.p9 = 0;
        _this.ab = ColumnSeries.$;
        _this.ps = 2;
        return _this;
    }
    ColumnSeries.prototype.bf = function () {
        return new ColumnSeriesView(this);
    };
    ColumnSeries.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.p8 = a;
    };
    ColumnSeries.prototype.m7 = function () {
        return 1;
    };
    ColumnSeries.prototype.get_nm = function () {
        return true;
    };
    ColumnSeries.prototype.preferredCategoryMode = function (a) {
        return this.ps;
    };
    ColumnSeries.prototype.ll = function (a) {
        if (this.qe == null) {
            this.qe = runOn(this, this.qb);
        }
        var b = this.pv != null ? this.pv : this.yAxis;
        var c = this.pp;
        return this.ou.c$d(this, a, c, b, this.my, this.ny(this.bi), this.nz(this.bi), this.qe);
    };
    ColumnSeries.prototype.df = function (a, b) {
        if (this.di(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    };
    ColumnSeries.prototype.ho = function (a, b) {
        _super.prototype.ho.call(this, a, b);
        var c = b;
        if (a && c.c7 != null) {
            c.c7.count = 0;
        }
    };
    ColumnSeries.prototype.ec = function () {
        return this.pp.jk(this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi));
    };
    ColumnSeries.prototype.of = function (a, b) {
        _super.prototype.of.call(this, a, b);
        var c = a.f;
        if (!b.q()) {
            return;
        }
        var d = b.bs;
        var e = b.br;
        var f = this.getEffectiveViewport1(b);
        var g = new ScalerParams(0, d, e, this.pv.b8, f);
        g.b = this.ed();
        var h = new ScalerParams(0, d, e, this.pp.b8, f);
        var i = this.pv;
        var j = i.dt(i.j7, g);
        var k = this.pp.jk(d, e, f);
        var l = this.pp;
        var m = b;
        if (isNaN_(k) || isInfinity(k)) {
            m.c7.count = 0;
            return;
        }
        this.m5.x(this, this.nq(), this.pp, runOn(this, this.mr), this.ny(b), this.nz(b));
        this.m5.p = this.qc;
        this.m5.q = this.qd;
        this.m5.j = this.qc;
        this.m5.k = this.qd;
        var n = false;
        var o = this.m5.c;
        if (o != null) {
            n = true;
        }
        var p = this.pp.cc;
        var q = p ? this.pp : null;
        var r = this.valueColumn.count;
        var s = this.ny(b);
        var t = 0;
        for (var u = 0; u < c.count; ++u) {
            var v = c._inner[u][0] - 0.5 * k;
            var w = this.qb(c._inner[u]);
            var x = j;
            w = Math.max(w, -100);
            x = Math.min(x, e.bottom + 100);
            var y = Math.abs(x - w);
            if (isInfinity(y)) {
                continue;
            }
            var z = m.c7.item(t);
            t++;
            z.width = k;
            z.height = y;
            if (n) {
                this.ob(c, u, r, l, h, b.n);
            }
            if (z.dataContext != null) {
                var aa = z.dataContext;
                if (s == 1) {
                    var ab = this.m5.a(r, u)[0];
                    if (ab >= 0 && ab < this.bz.count) {
                        if (q != null && q.i$b != null && q.i$b.count > ab) {
                            ab = q.i$b._inner[ab];
                        }
                        aa.item = this.bz.item(ab);
                    }
                }
                else {
                    aa.item = null;
                }
            }
            this.m5.ae(z, false, false, false, false);
            z.al = this.m5.j;
            z.am = this.m5.k;
            m.dc(z, v, Math.min(x, w));
        }
        m.c7.count = t;
        b.cu(a);
    };
    Object.defineProperty(ColumnSeries.prototype, "qa", {
        get: function () {
            return this.p9;
        },
        set: function (a) {
            if (this.qa != a) {
                var b = this.qa;
                this.p9 = a;
                this.raisePropertyChanged("ConsolidatedColumnVerticalPosition", enumGetBox(ConsolidatedItemsPosition_$type, b), enumGetBox(ConsolidatedItemsPosition_$type, this.qa));
            }
        },
        enumerable: true,
        configurable: true
    });
    ColumnSeries.prototype.qb = function (a) {
        if (a == null || a.length < 3) {
            return NaN;
        }
        switch (this.qa) {
            case 0: return a[1];
            case 1: return a[2];
            case 2: return (a[1] + a[2]) / 2;
            case 3:
                var b = (a[1] + a[2]) / 2;
                if (this.yAxis == null) {
                    return b;
                }
                var c = this.yAxis.dw(b, new ScalerParams(1, this.bs.m1, this.bs.m0, this.yAxis.b8));
                if (c < this.yAxis.j7) {
                    return a[2];
                }
                else {
                    return a[1];
                }
            case 4:
                var d = (a[1] + a[2]) / 2;
                var e = this.yAxis.dw(d, new ScalerParams(1, this.bs.m1, this.bs.m0, this.yAxis.b8));
                if (this.yAxis == null) {
                    return d;
                }
                if (e < this.yAxis.j7) {
                    return a[1];
                }
                else {
                    return a[2];
                }
            default: return (a[1] + a[2]) / 2;
        }
    };
    Object.defineProperty(ColumnSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.nt;
        },
        enumerable: true,
        configurable: true
    });
    ColumnSeries.$t = markType(ColumnSeries, 'ColumnSeries', HorizontalAnchoredCategorySeries.$);
    return ColumnSeries;
}(HorizontalAnchoredCategorySeries));
export { ColumnSeries };
Type.dep(DependencyProperty, PropertyMetadata, ColumnSeries, 'raisePropertyChanged', ['RadiusX:qc:qi', [1, 2], 'RadiusY:qd:qj', [1, 2]]);
var ColumnSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(ColumnSeriesView, _super);
    function ColumnSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c6 = null;
        _this.c8 = null;
        _this.dd = new Rectangle();
        _this.c7 = null;
        _this.c6 = a;
        _this.c7 = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.de);
            $ret.activate = runOn(_this, _this.c9);
            $ret.disactivate = runOn(_this, _this.db);
            $ret.destroy = runOn(_this, _this.da);
            return $ret;
        })());
        return _this;
    }
    ColumnSeriesView.prototype.ap = function () {
        _super.prototype.ap.call(this);
        this.c8 = new List$1(Rectangle.$, 0);
        if (!this.n) {
            this.e.eq = 4;
            this.e.bj = 1;
        }
    };
    ColumnSeriesView.prototype.de = function () {
        var a = new Rectangle();
        this.c8.add(a);
        a._visibility = 1;
        return a;
    };
    ColumnSeriesView.prototype.c9 = function (a) {
        a._visibility = 0;
    };
    ColumnSeriesView.prototype.db = function (a) {
        a._visibility = 1;
    };
    ColumnSeriesView.prototype.da = function (a) {
        this.c8.remove(a);
    };
    ColumnSeriesView.prototype.dc = function (a, b, c) {
        if (!this.isDirty) {
            this.an();
        }
        a.o = c;
        a.n = b;
    };
    ColumnSeriesView.prototype.z = function (a) {
        return this.c8._inner[a];
    };
    ColumnSeriesView.prototype.y = function (a) {
        var b = this.c8._inner[a];
        this.dd._visibility = b._visibility;
        this.dd.n = b.n;
        this.dd.o = b.o;
        this.dd.width = b.width;
        this.dd.height = b.height;
        var c = this.bm(a);
        this.dd._fill = c;
        this.dd._stroke = c;
        this.dd.ac = this.e.eu + 3;
        return this.dd;
    };
    ColumnSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d) {
            for (var c = 0; c < this.c8.count; c++) {
                var d = this.x(c, b);
                this.ba(d, c, b);
                a.v(d);
            }
        }
    };
    ColumnSeriesView.prototype.ai = function (a) {
        var e_1, _a, e_2, _b;
        _super.prototype.ai.call(this, a);
        var b = 0;
        var c = new List$1(Rectangle.$, 0);
        try {
            for (var _c = tslib_1.__values(fromEnum(this.c7.a)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var d = _d.value;
                c.add(d);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
            }
            finally { if (e_1) throw e_1.error; }
        }
        c.aa(function (e, f) {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        try {
            for (var _e = tslib_1.__values(fromEnum(c)), _f = _e.next(); !_f.done; _f = _e.next()) {
                var e = _f.value;
                this.e.a2.exportRectangleData(a, e, "column" + b, ["Main", "Fill"]);
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return)) _b.call(_e);
            }
            finally { if (e_2) throw e_2.error; }
        }
        b++;
    };
    ColumnSeriesView.$t = markType(ColumnSeriesView, 'ColumnSeriesView', AnchoredCategorySeriesView.$);
    return ColumnSeriesView;
}(AnchoredCategorySeriesView));
export { ColumnSeriesView };
